@@ -1,4 +1,4 @@
-
+import sys
 '''csv'''
 import csv
 
@@ -17,7 +17,7 @@ with open('example.txt') as csv_file:
 '''csv'''
 
 '''pandas'''
-for i in loop:
+for i in range(1, 10):
     print(i)
 '''pandas'''
 
@@ -37,6 +37,6 @@ class ClassName:
 
 
 '''arg'''
-print 'Number of arguments:', len(sys.argv), 'arguments.'
-print 'Argument List:', str(sys.argv)
+print('Number of arguments:', len(sys.argv), 'arguments.')
+print('Argument List:', str(sys.argv))
 '''arg'''
